@@ -6,7 +6,7 @@ import gc
 import torch
 import matplotlib.pyplot as plt
 from IPython.display import display, clear_output
-from dlogicutils.ju import disablePrint, enablePrint, force_print
+from dl2050utils.ju import disablePrint, enablePrint, force_print
 from nn2.etc import *
 from nn2.cbs import Callback
 from nn2.metrics import *
